import _inheritsLoose from "@babel/runtime/helpers/esm/inheritsLoose";
import React, { Component } from 'react';
import PropTypes from 'prop-types';
import { mapLanguages, mapViewModes, NO_OP } from './leaflet/constants';

var MapBasic =
/*#__PURE__*/
function (_Component) {
  _inheritsLoose(MapBasic, _Component);

  function MapBasic(props) {
    var _this;

    _this = _Component.call(this, props) || this;

    _this.setMapEventDefinition();

    _this.isHeatmapVisible = false;
    _this.isSatelliteView = false;
    _this.mapInstance = undefined;
    return _this;
  }

  var _proto = MapBasic.prototype;

  _proto.setMapEventDefinition = function setMapEventDefinition() {
    var _this2 = this;

    this.mapEventList = [{
      name: 'leaflet_map_click',
      handleFunction: function handleFunction(evt) {
        return _this2.props.onMapClick(evt.detail);
      }
    }, {
      name: 'leaflet_map_dragend',
      handleFunction: function handleFunction(evt) {
        return _this2.props.onMapDragEnd(evt.detail);
      }
    }, {
      name: 'leaflet_map_loaded',
      handleFunction: function handleFunction(evt) {
        return _this2.props.onMapLoad(evt.detail);
      }
    }, {
      name: 'leaflet_map_zoomend',
      handleFunction: function handleFunction(evt) {
        return _this2.props.onMapZoomEnd(evt.detail);
      }
    }, {
      name: 'leaflet_map_layer_normal',
      handleFunction: function handleFunction(evt) {
        return _this2.props.onNormalView(evt.detail);
      }
    }, {
      name: 'leaflet_map_poiclick',
      handleFunction: function handleFunction(evt) {
        return _this2.props.onPoiClick(evt.detail);
      }
    }, {
      name: 'leaflet_map_poimouseout',
      handleFunction: function handleFunction() {
        return _this2.props.onPoiMouseOut();
      }
    }, {
      name: 'leaflet_map_poimouseover',
      handleFunction: function handleFunction(evt) {
        return _this2.props.onPoiMouseOver(evt.detail);
      }
    }, {
      name: 'leaflet_map_poimousemove',
      handleFunction: function handleFunction(evt) {
        return _this2.props.onPoiMouseMove(evt.detail);
      }
    }, {
      name: 'leaflet_map_layer_satellite',
      handleFunction: function handleFunction(evt) {
        return _this2.props.onSatelliteView(evt.detail);
      }
    }];
  };

  _proto.getMapConfig = function getMapConfig() {
    return {
      appCode: this.props.appCode,
      appId: this.props.appId,
      attribution: this.props.attribution,
      currentGeoCode: this.props.currentGeoCode,
      dragging: this.props.isInteractable,
      enableViewMenu: this.props.enableViewMenu,
      heatMapUrl: this.props.heatMapUrl,
      hoverStyles: this.props.hoverStyles,
      icons: this.props.icons,
      id: this.props.id,
      language: this.props.language,
      latitude: this.props.center[0],
      literals: this.props.literals,
      longitude: this.props.center[1],
      mapDOMInstance: this.mapDOMInstance,
      mapViewModes: this.props.mapViewModes,
      maxZoom: this.props.maxZoom,
      minZoom: this.props.minZoom,
      onLayerClick: this.props.onLayerClick,
      onPolygonWithBounds: this.props.onPolygonWithBounds,
      polygons: this.props.polygons,
      radius: this.props.radius,
      scrollWheelZoom: this.props.scrollWheelZoom,
      selectedMapViewMode: this.props.selectedMapViewMode,
      showHeatmap: this.props.showHeatmap,
      showLabels: this.props.showLabels,
      showSatelliteView: this.props.showSatelliteView,
      zoom: this.props.zoom,
      zoomControl: this.props.zoomable,
      zoomControlPosition: this.props.zoomControlPosition
    };
  };

  _proto.subscribeToMapEvents = function subscribeToMapEvents() {
    var _this3 = this;

    this.mapEventList.forEach(function (mapEvent) {
      return _this3.mapDOMInstance.addEventListener(mapEvent.name, mapEvent.handleFunction);
    });
  };

  _proto.unsubscribeFromMapEvents = function unsubscribeFromMapEvents() {
    var _this4 = this;

    this.mapEventList.forEach(function (mapEvent) {
      return _this4.mapDOMInstance.removeEventListener(mapEvent.name, mapEvent.handleFunction);
    });
  };

  _proto.checkWhichViewShouldBeDisplayed = function checkWhichViewShouldBeDisplayed(showSatelliteView) {
    if (showSatelliteView && !this.isSatelliteView) {
      this.isSatelliteView = true;
      this.mapInstance.setView(mapViewModes.SATELLITE);
    } else if (!showSatelliteView && this.isSatelliteView) {
      this.isSatelliteView = false;
      this.mapInstance.setView(mapViewModes.NORMAL);
    }
  };

  _proto.checkIfHeatMapShouldBeDisplayed = function checkIfHeatMapShouldBeDisplayed(showHeatmap, url) {
    if (showHeatmap && !this.isHeatmapVisible) {
      this.isHeatmapVisible = true;
      this.mapInstance.showHeatMap(url);
    } else if (!showHeatmap && this.isHeatmapVisible) {
      this.isHeatmapVisible = false;
      this.mapInstance.removeHeatMapLayer();
    }
  };

  _proto.componentWillUnmount = function componentWillUnmount() {
    this.unsubscribeFromMapEvents();
  };

  _proto.shouldComponentUpdate = function shouldComponentUpdate() {
    // The component itself has no changes. All changes are managed through leaflet maps api.
    return false;
  };

  _proto.UNSAFE_componentWillReceiveProps = function UNSAFE_componentWillReceiveProps(_ref) {
    var heatMapUrl = _ref.heatMapUrl,
        pois = _ref.pois,
        showHeatmap = _ref.showHeatmap,
        showSatelliteView = _ref.showSatelliteView;
    this.mapInstance.displayPois(pois);
    this.checkIfHeatMapShouldBeDisplayed(showHeatmap, heatMapUrl);
    this.checkWhichViewShouldBeDisplayed(showSatelliteView);
  };

  _proto.componentDidMount = function componentDidMount() {
    var LeafletMap = require('./leaflet/map')["default"];

    this.subscribeToMapEvents();
    this.mapInstance = new LeafletMap(this.getMapConfig());
    this.mapInstance.displayPois(this.props.pois);
  };

  _proto.render = function render() {
    var _this5 = this;

    return React.createElement("div", {
      className: "re-Wrapper sui-MapBasic",
      style: this.props.height && {
        height: this.props.height
      },
      ref: function ref(ele) {
        _this5.mapDOMInstance = ele;
      },
      id: this.props.id
    });
  };

  return MapBasic;
}(Component);

MapBasic.defaultProps = {
  attribution: 'Map &copy; 1987-2019 <a href="http://developer.here.com">HERE</a>',
  center: [40.00237, -3.99902],
  currentGeoCode: [],
  id: 'map-container',
  isInteractable: true,
  language: mapLanguages.ENGLISH,
  mapViewModes: [mapViewModes.NORMAL, mapViewModes.SATELLITE],
  maxZoom: 20,
  minZoom: 6,
  onLayerClick: NO_OP,
  onMapClick: NO_OP,
  onMapDragEnd: NO_OP,
  onMapLoad: NO_OP,
  onMapZoomEnd: NO_OP,
  onNormalView: NO_OP,
  onPoiClick: NO_OP,
  onPoiMouseMove: NO_OP,
  onPoiMouseOut: NO_OP,
  onPoiMouseOver: NO_OP,
  onPolygonWithBounds: function onPolygonWithBounds(_ref2) {
    var bounds = _ref2.bounds,
        map = _ref2.map;
    return bounds && map.fitBounds(bounds);
  },
  onSatelliteView: NO_OP,
  scrollWheelZoom: true,
  selectedMapViewMode: 0,
  showLabels: false,
  zoom: 14,
  zoomable: false,
  zoomControlPosition: 'bottomleft'
};
MapBasic.displayName = 'MapBasic';
export default MapBasic;
export { mapLanguages };